<?php
/**
* @package phpBB Extension - ACP Styled
* @copyright (c) 2024 Sniper_E - https://www.sniper-e.net
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*/

namespace sniper\acpstyled\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class listener implements EventSubscriberInterface
{
	/** @var \phpbb\config\config */
	protected $config;
	/** @var \phpbb\template\template */
	protected $template;
	/** @var \phpbb\user */
	protected $user;
	/** @var \phpbb\request\request */
	protected $request;
	/** @var \phpbb\extension\manager */
	protected $extension_manager;
	/**
	* Constructor
	*
	* @param \phpbb\config\config       $config
	* @param \phpbb\template\template   $template
	* @param \phpbb\user                $user
	* @param \phpbb\request\request     $request
	* @param \phpbb\extension\manager 	$extension_manager
	*/
	public function __construct(
		\phpbb\config\config $config,
		\phpbb\template\template $template,
		\phpbb\user $user,
		\phpbb\request\request $request,
		\phpbb\extension\manager $extension_manager
	)
	{
		$this->config            = $config;
		$this->template          = $template;
		$this->user              = $user;
		$this->request           = $request;
		$this->extension_manager = $extension_manager;
	}

	static public function getSubscribedEvents()
	{
		return array(
			'core.adm_page_header' 	=> 'adm_page_header',
		);
	}

	public function adm_page_header($event)
	{
		$md_manager = $this->extension_manager->create_extension_metadata_manager('sniper/acpstyled', $this->template);
		$meta = $md_manager->get_metadata();

		$this->template->assign_vars(array(
			'ACP_SITENAME'            => $this->config['sitename'],
			'ACP_DARK_STYLE'          => $this->config['admin_dark_style'],
			'ACP_HEADER_IMAGE'        => $this->config['admin_header_image'],
			'ACPSTYLED_VERSION'       => $meta['version'],
		));
	}
}
